@@ -21,14 +21,13 @@
  * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
-#include <ktexteditor/view.h>
 #include <ktexteditor/document.h>
+#include <ktexteditor/view.h>
 
-#include <ktexteditor/application.h>
-#include <ktexteditor/mainwindow.h>
 #include <KTextEditor/ConfigPage>
 #include <KTextEditor/Plugin>
+#include <ktexteditor/application.h>
+#include <ktexteditor/mainwindow.h>
 
 #include "kate_ctags_view.h"
 #include "ui_CTagsGlobalConfig.h"
@@ -38,33 +37,43 @@ class KateCTagsPlugin : public KTextEditor::Plugin
 {
     Q_OBJECT
 
-    public:
-        explicit KateCTagsPlugin(QObject* parent = 0, const QList<QVariant> & = QList<QVariant>());
-        virtual ~KateCTagsPlugin() {}
+public:
+    explicit KateCTagsPlugin(QObject *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
+    ~KateCTagsPlugin() override
+    {
+    }
 
-        QObject *createView(KTextEditor::MainWindow *mainWindow) Q_DECL_OVERRIDE;
-   
-        int configPages() const Q_DECL_OVERRIDE { return 1; };
-        KTextEditor::ConfigPage *configPage (int number = 0, QWidget *parent = 0) Q_DECL_OVERRIDE;
-        void readConfig();
-        
-        KateCTagsView *m_view;
+    QObject *createView(KTextEditor::MainWindow *mainWindow) override;
+
+    int configPages() const override
+    {
+        return 1;
+    }
+    KTextEditor::ConfigPage *configPage(int number = 0, QWidget *parent = nullptr) override;
+    void readConfig();
+
+    KateCTagsView *m_view = nullptr;
 };
 
 //******************************************************************/
-class KateCTagsConfigPage : public KTextEditor::ConfigPage {
+class KateCTagsConfigPage : public KTextEditor::ConfigPage
+{
     Q_OBJECT
 public:
-    explicit KateCTagsConfigPage( QWidget* parent = 0, KateCTagsPlugin *plugin = 0 );
-    ~KateCTagsConfigPage() {}
+    explicit KateCTagsConfigPage(QWidget *parent = nullptr, KateCTagsPlugin *plugin = nullptr);
+    ~KateCTagsConfigPage() override
+    {
+    }
 
-    QString name() const Q_DECL_OVERRIDE;
-    QString fullName() const Q_DECL_OVERRIDE;
-    QIcon icon() const Q_DECL_OVERRIDE;
-    
-    void apply() Q_DECL_OVERRIDE;
-    void reset() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE {}
+    QString name() const override;
+    QString fullName() const override;
+    QIcon icon() const override;
+
+    void apply() override;
+    void reset() override;
+    void defaults() override
+    {
+    }
 
 private Q_SLOTS:
     void addGlobalTagTarget();
@@ -73,13 +82,11 @@ private Q_SLOTS:
     void updateDone(int exitCode, QProcess::ExitStatus status);
 
 private:
-
     bool listContains(const QString &target);
 
-    QProcess              m_proc;
-    KateCTagsPlugin      *m_plugin;
-    Ui_CTagsGlobalConfig  m_confUi;
+    QProcess m_proc;
+    KateCTagsPlugin *m_plugin;
+    Ui_CTagsGlobalConfig m_confUi;
 };
 
 #endif
-
