@@ -24,13 +24,16 @@
 class KateProjectPlugin;
 class QWidget;
 class QCheckBox;
+class KUrlRequester;
 
 class KateProjectConfigPage : public KTextEditor::ConfigPage
 {
     Q_OBJECT
 public:
     explicit KateProjectConfigPage(QWidget *parent = nullptr, KateProjectPlugin *plugin = nullptr);
-    ~KateProjectConfigPage() override {}
+    ~KateProjectConfigPage() override
+    {
+    }
 
     QString name() const override;
     QString fullName() const override;
@@ -48,8 +51,12 @@ private:
     QCheckBox *m_cbAutoGit;
     QCheckBox *m_cbAutoSubversion;
     QCheckBox *m_cbAutoMercurial;
+    QCheckBox *m_cbIndexEnabled;
+    KUrlRequester *m_indexPath;
+    QCheckBox *m_cbMultiProjectCompletion;
+    QCheckBox *m_cbMultiProjectGoto;
     KateProjectPlugin *m_plugin;
-    bool m_changed;
+    bool m_changed = false;
 };
 
 #endif /* KATE_PROJECT_CONFIGPAGE_H */
