@@ -24,9 +24,9 @@
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
 
+#include <QStandardItemModel>
 #include <QStringList>
 #include <QTemporaryFile>
-#include <QStandardItemModel>
 
 /**
  * ctags reading
@@ -48,7 +48,7 @@ public:
      * @param files files to index
      * @param ctagsMap ctags section for extra options
      */
-    KateProjectIndex(const QStringList &files, const QVariantMap &ctagsMap);
+    KateProjectIndex(const QString &baseDir, const QString &indexDir, const QStringList &files, const QVariantMap &ctagsMap, bool force);
 
     /**
      * deconstruct project
@@ -77,15 +77,17 @@ public:
      * @param model model to fill with matches
      * @param searchWord word to search for
      * @param type type of matches
+     * @param options ctags find options (use default if -1)
      */
-    void findMatches(QStandardItemModel &model, const QString &searchWord, MatchType type);
+    void findMatches(QStandardItemModel &model, const QString &searchWord, MatchType type, int options = -1);
 
     /**
      * Check if running ctags was successful. This can be used
      * as indicator whether ctags is installed or not.
      * @return true if a valid index exists, otherwise false
      */
-    bool isValid() const {
+    bool isValid() const
+    {
         return m_ctagsIndexHandle;
     }
 
@@ -95,13 +97,18 @@ private:
      * @param files files to index
      * @param ctagsMap ctags section for extra options
      */
-    void loadCtags(const QStringList &files, const QVariantMap &ctagsMap);
+    void loadCtags(const QStringList &files, const QVariantMap &ctagsMap, bool force);
+
+    /**
+     * Open ctags tags.
+     */
+    void openCtags();
 
 private:
     /**
      * ctags index file
      */
-    QTemporaryFile m_ctagsIndexFile;
+    QScopedPointer<QFile> m_ctagsIndexFile;
 
     /**
      * handle to ctags file for querying, if possible
@@ -110,4 +117,3 @@ private:
 };
 
 #endif
-
