@@ -24,23 +24,25 @@
 #include "kateprojectconfigpage.h"
 #include "kateprojectpluginview.h"
 
-#include <ktexteditor/editor.h>
 #include <ktexteditor/application.h>
 #include <ktexteditor/document.h>
+#include <ktexteditor/editor.h>
+#include <ktexteditor_version.h> // delete, when we depend on KF 5.63
 
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
 #include <ThreadWeaver/Queue>
 
 #include <QFileInfo>
 #include <QTime>
 
-#include "config.h"
+#include <vector>
 
 #ifdef HAVE_CTERMID
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <fcntl.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <termios.h>
 #include <unistd.h>
 #endif
@@ -74,6 +76,9 @@ KateProjectPlugin::KateProjectPlugin(QObject *parent, const QList<QVariant> &)
     connect(KTextEditor::Editor::instance()->application(), &KTextEditor::Application::documentCreated, this, &KateProjectPlugin::slotDocumentCreated);
     connect(&m_fileWatcher, &QFileSystemWatcher::directoryChanged, this, &KateProjectPlugin::slotDirectoryChanged);
 
+    // read configuration prior to cwd project setup below
+    readConfig();
+
 #ifdef HAVE_CTERMID
     /**
      * open project for our current working directory, if this kate has a terminal
@@ -89,15 +94,17 @@ KateProjectPlugin::KateProjectPlugin(QObject *parent, const QList<QVariant> &)
     }
 #endif
 
-    readConfig();
-
     for (auto document : KTextEditor::Editor::instance()->application()->documents()) {
         slotDocumentCreated(document);
     }
+
+    registerVariables();
 }
 
 KateProjectPlugin::~KateProjectPlugin()
 {
+    unregisterVariables();
+
     for (KateProject *project : m_projects) {
         m_fileWatcher.removePath(QFileInfo(project->fileName()).canonicalPath());
         delete project;
@@ -128,8 +135,7 @@ KTextEditor::ConfigPage *KateProjectPlugin::configPage(int number, QWidget *pare
 
 KateProject *KateProjectPlugin::createProjectForFileName(const QString &fileName)
 {
-    KateProject *project = new KateProject(m_weaver);
-
+    KateProject *project = new KateProject(m_weaver, this);
     if (!project->loadFromFile(fileName)) {
         delete project;
         return nullptr;
@@ -144,45 +150,53 @@ KateProject *KateProjectPlugin::createProjectForFileName(const QString &fileName
 KateProject *KateProjectPlugin::projectForDir(QDir dir)
 {
     /**
-     * search projects upwards
+     * search project file upwards
      * with recursion guard
+     * do this first for all level and only after this fails try to invent projects
+     * otherwise one e.g. invents projects for .kateproject tree structures with sub .git clones
      */
     QSet<QString> seenDirectories;
+    std::vector<QString> directoryStack;
     while (!seenDirectories.contains(dir.absolutePath())) {
-        /**
-         * fill recursion guard
-         */
+        // update guard
         seenDirectories.insert(dir.absolutePath());
 
-        /**
-         * check for project and load it if found
-         */
-        QString canonicalPath = dir.canonicalPath();
-        QString canonicalFileName = dir.filePath(ProjectFileName);
+        // remember directory for later project creation based on other criteria
+        directoryStack.push_back(dir.absolutePath());
 
+        // check for project and load it if found
+        const QString canonicalPath = dir.canonicalPath();
+        const QString canonicalFileName = dir.filePath(ProjectFileName);
         for (KateProject *project : m_projects) {
             if (project->baseDir() == canonicalPath || project->fileName() == canonicalFileName) {
                 return project;
             }
         }
 
+        // project file found => done
         if (dir.exists(ProjectFileName)) {
             return createProjectForFileName(canonicalFileName);
         }
 
-        KateProject *project;
-        if ((project = detectGit(dir)) || (project = detectSubversion(dir)) || (project = detectMercurial(dir))) {
-            return project;
-        }
-
-        /**
-         * else: cd up, if possible or abort
-         */
+        // else: cd up, if possible or abort
         if (!dir.cdUp()) {
             break;
         }
     }
 
+    /**
+     * if we arrive here, we found no .kateproject
+     * => we want to invent a project based on e.g. version control system info
+     */
+    for (const QString &dir : directoryStack) {
+        // try to invent project based on version control stuff
+        KateProject *project = nullptr;
+        if ((project = detectGit(dir)) || (project = detectSubversion(dir)) || (project = detectMercurial(dir))) {
+            return project;
+        }
+    }
+
+    // no project found, bad luck
     return nullptr;
 }
 
@@ -234,7 +248,7 @@ void KateProjectPlugin::slotDocumentUrlChanged(KTextEditor::Document *document)
 void KateProjectPlugin::slotDirectoryChanged(const QString &path)
 {
     QString fileName = QDir(path).filePath(ProjectFileName);
-    for (KateProject * project : m_projects) {
+    for (KateProject *project : m_projects) {
         if (project->fileName() == fileName) {
             QDateTime lastModified = QFileInfo(fileName).lastModified();
             if (project->fileLastModified().isNull() || (lastModified > project->fileLastModified())) {
@@ -245,7 +259,7 @@ void KateProjectPlugin::slotDirectoryChanged(const QString &path)
     }
 }
 
-KateProject* KateProjectPlugin::detectGit(const QDir &dir)
+KateProject *KateProjectPlugin::detectGit(const QDir &dir)
 {
     // allow .git as dir and file (file for git worktree stuff, https://git-scm.com/docs/git-worktree)
     if (m_autoGit && dir.exists(GitFolderName)) {
@@ -255,7 +269,7 @@ KateProject* KateProjectPlugin::detectGit(const QDir &dir)
     return nullptr;
 }
 
-KateProject* KateProjectPlugin::detectSubversion(const QDir &dir)
+KateProject *KateProjectPlugin::detectSubversion(const QDir &dir)
 {
     if (m_autoSubversion && dir.exists(SubversionFolderName) && QFileInfo(dir, SubversionFolderName).isDir()) {
         return createProjectForRepository(QStringLiteral("svn"), dir);
@@ -264,7 +278,7 @@ KateProject* KateProjectPlugin::detectSubversion(const QDir &dir)
     return nullptr;
 }
 
-KateProject* KateProjectPlugin::detectMercurial(const QDir &dir)
+KateProject *KateProjectPlugin::detectMercurial(const QDir &dir)
 {
     if (m_autoMercurial && dir.exists(MercurialFolderName) && QFileInfo(dir, MercurialFolderName).isDir()) {
         return createProjectForRepository(QStringLiteral("hg"), dir);
@@ -280,7 +294,7 @@ KateProject *KateProjectPlugin::createProjectForRepository(const QString &type,
     cnf[QStringLiteral("name")] = dir.dirName();
     cnf[QStringLiteral("files")] = (QVariantList() << files);
 
-    KateProject *project = new KateProject(m_weaver);
+    KateProject *project = new KateProject(m_weaver, this);
     project->loadFromData(cnf, dir.canonicalPath());
 
     m_projects.append(project);
@@ -312,6 +326,40 @@ bool KateProjectPlugin::autoMercurial() const
     return m_autoMercurial;
 }
 
+void KateProjectPlugin::setIndex(bool enabled, const QUrl &directory)
+{
+    m_indexEnabled = enabled;
+    m_indexDirectory = directory;
+    writeConfig();
+}
+
+bool KateProjectPlugin::getIndexEnabled() const
+{
+    return m_indexEnabled;
+}
+
+QUrl KateProjectPlugin::getIndexDirectory() const
+{
+    return m_indexDirectory;
+}
+
+bool KateProjectPlugin::multiProjectCompletion() const
+{
+    return m_multiProjectCompletion;
+}
+
+bool KateProjectPlugin::multiProjectGoto() const
+{
+    return m_multiProjectGoto;
+}
+
+void KateProjectPlugin::setMultiProject(bool completion, bool gotoSymbol)
+{
+    m_multiProjectCompletion = completion;
+    m_multiProjectGoto = gotoSymbol;
+    writeConfig();
+}
+
 void KateProjectPlugin::readConfig()
 {
     KConfigGroup config(KSharedConfig::openConfig(), "project");
@@ -330,6 +378,14 @@ void KateProjectPlugin::readConfig()
     if (autorepository.contains(MercurialConfig)) {
         m_autoMercurial = true;
     }
+
+    m_indexEnabled = config.readEntry("index", false);
+    m_indexDirectory = config.readEntry("indexDirectory", QUrl());
+
+    m_multiProjectCompletion = config.readEntry("multiProjectCompletion", false);
+    m_multiProjectGoto = config.readEntry("multiProjectCompletion", false);
+
+    emit configUpdated();
 }
 
 void KateProjectPlugin::writeConfig()
@@ -350,4 +406,65 @@ void KateProjectPlugin::writeConfig()
     }
 
     config.writeEntry("autorepository", repos);
+
+    config.writeEntry("index", m_indexEnabled);
+    config.writeEntry("indexDirectory", m_indexDirectory);
+
+    config.writeEntry("multiProjectCompletion", m_multiProjectCompletion);
+    config.writeEntry("multiProjectGoto", m_multiProjectGoto);
+
+    emit configUpdated();
+}
+
+#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5, 63, 0)
+static KateProjectPlugin *findProjectPlugin()
+{
+    auto plugin = KTextEditor::Editor::instance()->application()->plugin(QStringLiteral("kateprojectplugin"));
+    return qobject_cast<KateProjectPlugin *>(plugin);
+}
+#endif
+
+void KateProjectPlugin::registerVariables()
+{
+#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5, 63, 0)
+    auto editor = KTextEditor::Editor::instance();
+    editor->registerVariableMatch(QStringLiteral("Project:Path"), i18n("Full path to current project excluding the file name."), [](const QStringView &, KTextEditor::View *view) {
+        if (!view) {
+            return QString();
+        }
+        auto projectPlugin = findProjectPlugin();
+        if (!projectPlugin) {
+            return QString();
+        }
+        auto kateProject = findProjectPlugin()->projectForUrl(view->document()->url());
+        if (!kateProject) {
+            return QString();
+        }
+        return QDir(kateProject->baseDir()).absolutePath();
+    });
+
+    editor->registerVariableMatch(QStringLiteral("Project:NativePath"), i18n("Full path to current project excluding the file name, with native path separator (backslash on Windows)."), [](const QStringView &, KTextEditor::View *view) {
+        if (!view) {
+            return QString();
+        }
+        auto projectPlugin = findProjectPlugin();
+        if (!projectPlugin) {
+            return QString();
+        }
+        auto kateProject = findProjectPlugin()->projectForUrl(view->document()->url());
+        if (!kateProject) {
+            return QString();
+        }
+        return QDir::toNativeSeparators(QDir(kateProject->baseDir()).absolutePath());
+    });
+#endif
+}
+
+void KateProjectPlugin::unregisterVariables()
+{
+#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5, 63, 0)
+    auto editor = KTextEditor::Editor::instance();
+    editor->unregisterVariableMatch(QStringLiteral("Project:Path"));
+    editor->unregisterVariableMatch(QStringLiteral("Project:NativePath"));
+#endif
 }
