@@ -1,23 +1,24 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2005 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2002, 2003 Joseph Wenninger <jowenn@kde.org>
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-   GUIClient partly based on ktoolbarhandler.cpp: Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>
+    Copyright (C) 2005 Christoph Cullmann <cullmann@kde.org>
+    Copyright (C) 2002, 2003 Joseph Wenninger <jowenn@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+    GUIClient partly based on ktoolbarhandler.cpp: Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "katemdi.h"
@@ -27,31 +28,30 @@
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KConfigGroup>
-#include <KMessageBox>
-#include <KXMLGUIFactory>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <KSharedConfig>
-#include <kwindowconfig.h>
 #include <KToolBar>
+#include <KXMLGUIFactory>
+#include <kwindowconfig.h>
 
 #include <QChildEvent>
-#include <QEvent>
 #include <QContextMenuEvent>
-#include <QPixmap>
+#include <QDomDocument>
+#include <QEvent>
 #include <QMenu>
+#include <QPixmap>
 #include <QShortcut>
 #include <QSizePolicy>
 #include <QStyle>
-#include <QDomDocument>
+#include <QTimer>
 #include <QVBoxLayout>
 
 namespace KateMDI
 {
-
-//BEGIN TOGGLETOOLVIEWACTION
+// BEGIN TOGGLETOOLVIEWACTION
 //
-ToggleToolViewAction::ToggleToolViewAction(const QString &text, ToolView *tv,
-        QObject *parent)
+ToggleToolViewAction::ToggleToolViewAction(const QString &text, ToolView *tv, QObject *parent)
     : KToggleAction(text, parent)
     , m_tv(tv)
 {
@@ -62,7 +62,8 @@ ToggleToolViewAction::ToggleToolViewAction(const QString &text, ToolView *tv,
 }
 
 ToggleToolViewAction::~ToggleToolViewAction()
-{}
+{
+}
 
 void ToggleToolViewAction::toolVisibleChanged(bool)
 {
@@ -81,29 +82,29 @@ void ToggleToolViewAction::slotToggled(bool t)
     }
 }
 
-//END TOGGLETOOLVIEWACTION
+// END TOGGLETOOLVIEWACTION
 
-//BEGIN GUICLIENT
+// BEGIN GUICLIENT
 
 static const QString actionListName = QStringLiteral("kate_mdi_view_actions");
 
 // please don't use QStringLiteral since it can't be used with a concatenated string parameter on all platforms
-static const QString guiDescription = QStringLiteral(""
-                                      "<!DOCTYPE kpartgui><kpartgui name=\"kate_mdi_view_actions\">"
-                                      "<MenuBar>"
-                                      "    <Menu name=\"view\">"
-                                      "        <ActionList name=\"%1\" />"
-                                      "    </Menu>"
-                                      "</MenuBar>"
-                                      "</kpartgui>");
+static const QString guiDescription = QStringLiteral(
+    ""
+    "<!DOCTYPE kpartgui><kpartgui name=\"kate_mdi_view_actions\">"
+    "<MenuBar>"
+    "    <Menu name=\"view\">"
+    "        <ActionList name=\"%1\" />"
+    "    </Menu>"
+    "</MenuBar>"
+    "</kpartgui>");
 
 GUIClient::GUIClient(MainWindow *mw)
     : QObject(mw)
     , KXMLGUIClient(mw)
     , m_mw(mw)
 {
-    connect(m_mw->guiFactory(), &KXMLGUIFactory::clientAdded,
-            this, &GUIClient::clientAdded);
+    connect(m_mw->guiFactory(), &KXMLGUIFactory::clientAdded, this, &GUIClient::clientAdded);
 
     if (domDocument().documentElement().isNull()) {
         QString completeDescription = guiDescription.arg(actionListName);
@@ -130,12 +131,14 @@ GUIClient::GUIClient(MainWindow *mw)
     actionCollection()->readSettings();
 
     actionCollection()->addAssociatedWidget(m_mw);
-    foreach(QAction * action, actionCollection()->actions())
-    action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    const auto actions = actionCollection()->actions();
+    for (QAction *action : actions)
+        action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
 }
 
 GUIClient::~GUIClient()
-{}
+{
+}
 
 void GUIClient::updateSidebarsVisibleAction()
 {
@@ -152,7 +155,8 @@ void GUIClient::registerToolView(ToolView *tv)
     KSharedConfigPtr cfg = KSharedConfig::openConfig();
     QString shortcutString = cfg->group("Shortcuts").readEntry(aname, QString());
 
-    foreach(const QString & shortcut, shortcutString.split(QLatin1String(";"))) {
+    const auto shortcutStrings = shortcutString.split(QLatin1Char(';'));
+    for (const QString &shortcut : shortcutStrings) {
         shortcuts << QKeySequence::fromString(shortcut);
     }
 
@@ -205,9 +209,9 @@ void GUIClient::updateActions()
     plugActionList(actionListName, addList);
 }
 
-//END GUICLIENT
+// END GUICLIENT
 
-//BEGIN TOOLVIEW
+// BEGIN TOOLVIEW
 
 ToolView::ToolView(MainWindow *mainwin, Sidebar *sidebar, QWidget *parent)
     : QFrame(parent)
@@ -281,7 +285,7 @@ void ToolView::childEvent(QChildEvent *ev)
     QFrame::childEvent(ev);
 }
 
-void ToolView::actionEvent(QActionEvent* event)
+void ToolView::actionEvent(QActionEvent *event)
 {
     QFrame::actionEvent(event);
     if (event->type() == QEvent::ActionAdded) {
@@ -292,9 +296,9 @@ void ToolView::actionEvent(QActionEvent* event)
     m_toolbar->setVisible(!m_toolbar->actions().isEmpty());
 }
 
-//END TOOLVIEW
+// END TOOLVIEW
 
-//BEGIN SIDEBAR
+// BEGIN SIDEBAR
 
 Sidebar::Sidebar(KMultiTabBar::KMultiTabBarPosition pos, MainWindow *mainwin, QWidget *parent)
     : KMultiTabBar(pos, parent)
@@ -307,7 +311,8 @@ Sidebar::Sidebar(KMultiTabBar::KMultiTabBarPosition pos, MainWindow *mainwin, QW
 }
 
 Sidebar::~Sidebar()
-{}
+{
+}
 
 void Sidebar::setSplitter(QSplitter *sp)
 {
@@ -404,11 +409,21 @@ bool Sidebar::showWidget(ToolView *widget)
 
     // hide other non-persistent views
     QMapIterator<int, ToolView *> it(m_idToWidget);
+    bool unfixSize = false;
     while (it.hasNext()) {
         it.next();
         if ((it.value() != widget) && !it.value()->persistent) {
             hideWidget(it.value());
         }
+        // lock persistents' size while show/hide reshuffle happens
+        // (could also make this behavior per-widget configurable)
+        if (it.value()->persistent) {
+            auto w = it.value();
+            auto s = w->size();
+            w->setMinimumSize(s);
+            w->setMaximumSize(s);
+            unfixSize = true;
+        }
     }
 
     setTab(m_widgetToId[widget], true);
@@ -431,6 +446,20 @@ bool Sidebar::showWidget(ToolView *widget)
     m_ownSplit->show();
     widget->show();
 
+    // release persistent size again
+    // (later on, when all event processing has happened)
+    auto func = [this]() {
+        auto wsizes = m_ownSplit->sizes();
+        for (auto w : m_idToWidget) {
+            w->setMinimumSize(QSize(0, 0));
+            w->setMaximumSize(QSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX));
+        }
+        m_ownSplit->setSizes(wsizes);
+    };
+    if (unfixSize) {
+        QTimer::singleShot(0, this, func);
+    }
+
     /**
      * we are visible again!
      */
@@ -496,10 +525,10 @@ void Sidebar::tabClicked(int i)
 bool Sidebar::eventFilter(QObject *obj, QEvent *ev)
 {
     if (ev->type() == QEvent::ContextMenu) {
-        QContextMenuEvent *e = (QContextMenuEvent *) ev;
+        QContextMenuEvent *e = (QContextMenuEvent *)ev;
         KMultiTabBarTab *bt = dynamic_cast<KMultiTabBarTab *>(obj);
         if (bt) {
-            //qCDebug(LOG_KATE) << "Request for popup";
+            // qCDebug(LOG_KATE) << "Request for popup";
 
             m_popupButton = bt->id();
 
@@ -516,8 +545,7 @@ bool Sidebar::eventFilter(QObject *obj, QEvent *ev)
 
                 menu->addSection(QIcon::fromTheme(QStringLiteral("view_remove")), i18n("Behavior"));
 
-                menu->addAction(w->persistent ? QIcon::fromTheme(QStringLiteral("view-restore")) : QIcon::fromTheme(QStringLiteral("view-fullscreen")),
-                                w->persistent ? i18n("Make Non-Persistent") : i18n("Make Persistent")) -> setData(10);
+                menu->addAction(w->persistent ? QIcon::fromTheme(QStringLiteral("view-restore")) : QIcon::fromTheme(QStringLiteral("view-fullscreen")), w->persistent ? i18n("Make Non-Persistent") : i18n("Make Persistent"))->setData(10);
 
                 menu->addSection(QIcon::fromTheme(QStringLiteral("move")), i18n("Move To"));
 
@@ -572,7 +600,7 @@ void Sidebar::buttonPopupActivate(QAction *a)
     // move ids
     if (id < 4) {
         // move + show ;)
-        m_mainWin->moveToolView(w, (KMultiTabBar::KMultiTabBarPosition) id);
+        m_mainWin->moveToolView(w, (KMultiTabBar::KMultiTabBarPosition)id);
         m_mainWin->showToolView(w);
     }
 
@@ -680,9 +708,7 @@ void Sidebar::restoreSession(KConfigGroup &config)
 
     // show only correct toolviews, remember persistent values ;)
     bool anyVis = false;
-    for (int i = 0; i < m_toolviews.size(); ++i) {
-        ToolView *tv = m_toolviews[i];
-
+    for (auto tv : qAsConst(m_toolviews)) {
         tv->persistent = config.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Persistent").arg(tv->id), false);
         tv->setToolVisible(config.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Visible").arg(tv->id), false));
 
@@ -723,14 +749,12 @@ void Sidebar::saveSession(KConfigGroup &config)
     }
 }
 
-//END SIDEBAR
+// END SIDEBAR
 
-//BEGIN MAIN WINDOW
+// BEGIN MAIN WINDOW
 
 MainWindow::MainWindow(QWidget *parentWidget)
     : KParts::MainWindow(parentWidget, Qt::Window)
-    , m_sidebarsVisible(true)
-    , m_restoreConfig(nullptr)
     , m_guiClient(new GUIClient(this))
 {
     // init the internal widgets
@@ -781,10 +805,9 @@ MainWindow::MainWindow(QWidget *parentWidget)
     hlayout->addWidget(m_sidebars[KMultiTabBar::Right]);
     m_sidebars[KMultiTabBar::Right]->setSplitter(m_hSplitter);
 
-    for (int i = 0; i < 4; i++) {
-        connect(m_sidebars[i], &Sidebar::sigShowPluginConfigPage, this, &MainWindow::sigShowPluginConfigPage);
+    for (const auto sidebar : qAsConst(m_sidebars)) {
+        connect(sidebar, &Sidebar::sigShowPluginConfigPage, this, &MainWindow::sigShowPluginConfigPage);
     }
-
 }
 
 MainWindow::~MainWindow()
@@ -796,8 +819,8 @@ MainWindow::~MainWindow()
     delete m_centralWidget;
 
     // cleanup the sidebars
-    for (unsigned int i = 0; i < 4; ++i) {
-        delete m_sidebars[i];
+    for (auto sidebar : qAsConst(m_sidebars)) {
+        delete sidebar;
     }
 }
 
@@ -815,10 +838,10 @@ ToolView *MainWindow::createToolView(KTextEditor::Plugin *plugin, const QString
     // try the restore config to figure out real pos
     if (m_restoreConfig && m_restoreConfig->hasGroup(m_restoreGroup)) {
         KConfigGroup cg(m_restoreConfig, m_restoreGroup);
-        pos = (KMultiTabBar::KMultiTabBarPosition) cg.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Position").arg(identifier), int(pos));
+        pos = (KMultiTabBar::KMultiTabBarPosition)cg.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Position").arg(identifier), int(pos));
     }
 
-    ToolView *v  = m_sidebars[pos]->addWidget(icon, text, nullptr);
+    ToolView *v = m_sidebars[pos]->addWidget(icon, text, nullptr);
     v->id = identifier;
     v->plugin = plugin;
 
@@ -853,7 +876,6 @@ void MainWindow::toolViewDeleted(ToolView *widget)
 
     m_idToWidget.remove(widget->id);
     m_toolviews.removeAt(m_toolviews.indexOf(widget));
-
 }
 
 void MainWindow::setSidebarsVisible(bool visible)
@@ -878,7 +900,8 @@ void MainWindow::setSidebarsVisible(bool visible)
                                       "invoke <b>View &gt; Tool Views &gt; Show Sidebars</b> "
                                       "in the menu. It is still possible to show/hide "
                                       "the tool views with the assigned shortcuts.</qt>"),
-                                 QString(), QStringLiteral("Kate hide sidebars notification message"));
+                                 QString(),
+                                 QStringLiteral("Kate hide sidebars notification message"));
     }
 }
 
@@ -910,7 +933,7 @@ bool MainWindow::moveToolView(ToolView *widget, KMultiTabBar::KMultiTabBarPositi
     // try the restore config to figure out real pos
     if (m_restoreConfig && m_restoreConfig->hasGroup(m_restoreGroup)) {
         KConfigGroup cg(m_restoreConfig, m_restoreGroup);
-        pos = (KMultiTabBar::KMultiTabBarPosition) cg.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Position").arg(widget->id), int(pos));
+        pos = (KMultiTabBar::KMultiTabBarPosition)cg.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Position").arg(widget->id), int(pos));
     }
 
     m_sidebars[pos]->addWidget(widget->icon, widget->text, widget);
@@ -943,7 +966,7 @@ bool MainWindow::hideToolView(ToolView *widget)
         return true;
     }
 
-    const bool ret =  widget->sidebar()->hideWidget(widget);
+    const bool ret = widget->sidebar()->hideWidget(widget);
     m_centralWidget->setFocus();
     return ret;
 }
@@ -993,17 +1016,17 @@ void MainWindow::finishRestore()
         applyMainWindowSettings(cg);
 
         // reshuffle toolviews only if needed
-        for (int i = 0; i < m_toolviews.size(); ++i) {
-            KMultiTabBar::KMultiTabBarPosition newPos = (KMultiTabBar::KMultiTabBarPosition) cg.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Position").arg(m_toolviews[i]->id), int(m_toolviews[i]->sidebar()->position()));
+        for (const auto tv : qAsConst(m_toolviews)) {
+            KMultiTabBar::KMultiTabBarPosition newPos = (KMultiTabBar::KMultiTabBarPosition)cg.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Position").arg(tv->id), int(tv->sidebar()->position()));
 
-            if (m_toolviews[i]->sidebar()->position() != newPos) {
-                moveToolView(m_toolviews[i], newPos);
+            if (tv->sidebar()->position() != newPos) {
+                moveToolView(tv, newPos);
             }
         }
 
         // restore the sidebars
-        for (unsigned int i = 0; i < 4; ++i) {
-            m_sidebars[i]->restoreSession(cg);
+        for (auto sidebar : qAsConst(m_sidebars)) {
+            sidebar->restoreSession(cg);
         }
 
         // restore splitter sizes
@@ -1057,12 +1080,11 @@ void MainWindow::saveSession(KConfigGroup &config)
     config.writeEntry("Kate-MDI-Sidebar-Visible", m_sidebarsVisible);
 
     // save the sidebars
-    for (unsigned int i = 0; i < 4; ++i) {
-        m_sidebars[i]->saveSession(config);
+    for (auto sidebar : qAsConst(m_sidebars)) {
+        sidebar->saveSession(config);
     }
 }
 
-//END MAIN WINDOW
+// END MAIN WINDOW
 
 } // namespace KateMDI
-
