@@ -25,24 +25,24 @@
 
 #include <KAboutData>
 #include <KConfigGroup>
-#include <KLocalizedString>
-#include <KWindowSystem>
-#include <KStartupInfo>
-#include <kdbusservice.h>
 #include <KCrash>
+#include <KLocalizedString>
 #include <KSharedConfig>
+#include <KStartupInfo>
+#include <KWindowSystem>
+#include <kdbusservice.h>
 
+#include <QApplication>
 #include <QByteArray>
 #include <QCommandLineParser>
-#include <QTextCodec>
-#include <QUrl>
-#include <QVariant>
 #include <QDBusInterface>
 #include <QDBusMessage>
 #include <QDBusReply>
-#include <QApplication>
 #include <QDir>
 #include <QSessionManager>
+#include <QTextCodec>
+#include <QUrl>
+#include <QVariant>
 
 #include "../urlinfo.h"
 
@@ -55,7 +55,6 @@
 #endif
 #include <iostream>
 
-
 int main(int argc, char **argv)
 {
 #ifndef Q_OS_WIN
@@ -85,7 +84,7 @@ int main(int argc, char **argv)
      * Create application first
      */
 #ifdef USE_QT_SINGLE_APP
-    SharedTools::QtSingleApplication app(QStringLiteral("kate"),argc, argv);
+    SharedTools::QtSingleApplication app(QStringLiteral("kate"), argc, argv);
 #else
     QApplication app(argc, argv);
 #endif
@@ -108,9 +107,8 @@ int main(int argc, char **argv)
     /**
      * construct about data for Kate
      */
-    KAboutData aboutData(QStringLiteral("kate"), i18n("Kate"), QStringLiteral(KATE_VERSION),
-                         i18n("Kate - Advanced Text Editor"), KAboutLicense::LGPL_V2,
-                         i18n("(c) 2000-2019 The Kate Authors"), QString(), QStringLiteral("https://kate-editor.org"));
+    KAboutData aboutData(
+        QStringLiteral("kate"), i18n("Kate"), QStringLiteral(KATE_VERSION), i18n("Kate - Advanced Text Editor"), KAboutLicense::LGPL_V2, i18n("(c) 2000-2019 The Kate Authors"), QString(), QStringLiteral("https://kate-editor.org"));
 
     /**
      * right dbus prefix == org.kde.
@@ -165,7 +163,7 @@ int main(int argc, char **argv)
     /**
      * set the new Kate mascot
      */
-    aboutData.setProgramLogo (QImage(QStringLiteral(":/kate/mascot.png")));
+    aboutData.setProgramLogo(QImage(QStringLiteral(":/kate/mascot.png")));
 
     /**
      * set and register app about data
@@ -192,7 +190,9 @@ int main(int argc, char **argv)
     parser.addOption(startAnonymousSessionOption);
 
     // -n/--new option
-    const QCommandLineOption startNewInstanceOption(QStringList() << QStringLiteral("n") << QStringLiteral("new"), i18n("Force start of a new kate instance (is ignored if start is used and another kate instance already has the given session opened), forced if no parameters and no URLs are given at all."));
+    const QCommandLineOption startNewInstanceOption(
+        QStringList() << QStringLiteral("n") << QStringLiteral("new"),
+        i18n("Force start of a new kate instance (is ignored if start is used and another kate instance already has the given session opened), forced if no parameters and no URLs are given at all."));
     parser.addOption(startNewInstanceOption);
 
     // -b/--block option
@@ -200,7 +200,8 @@ int main(int argc, char **argv)
     parser.addOption(startBlockingOption);
 
     // -p/--pid option
-    const QCommandLineOption usePidOption(QStringList() << QStringLiteral("p") << QStringLiteral("pid"), i18n("Only try to reuse kate instance with this pid (is ignored if start is used and another kate instance already has the given session opened)."), i18n("pid"));
+    const QCommandLineOption usePidOption(
+        QStringList() << QStringLiteral("p") << QStringLiteral("pid"), i18n("Only try to reuse kate instance with this pid (is ignored if start is used and another kate instance already has the given session opened)."), i18n("pid"));
     parser.addOption(usePidOption);
 
     // -e/--encoding option
@@ -249,15 +250,9 @@ int main(int argc, char **argv)
      */
     bool force_new = parser.isSet(startNewInstanceOption);
     if (!force_new) {
-        if (!(
-                    parser.isSet(startSessionOption) ||
-                    parser.isSet(startNewInstanceOption) ||
-                    parser.isSet(usePidOption) ||
-                    parser.isSet(useEncodingOption) ||
-                    parser.isSet(gotoLineOption) ||
-                    parser.isSet(gotoColumnOption) ||
-                    parser.isSet(readStdInOption)
-                ) && (urls.isEmpty())) {
+        if (!(parser.isSet(startSessionOption) || parser.isSet(startNewInstanceOption) || parser.isSet(usePidOption) || parser.isSet(useEncodingOption) || parser.isSet(gotoLineOption) || parser.isSet(gotoColumnOption) ||
+              parser.isSet(readStdInOption)) &&
+            (urls.isEmpty())) {
             force_new = true;
         }
     }
@@ -272,7 +267,7 @@ int main(int argc, char **argv)
      * allows for reuse of running Kate instances
      */
 #ifndef USE_QT_SINGLE_APP
-    if (QDBusConnectionInterface * const sessionBusInterface = QDBusConnection::sessionBus().interface()) {
+    if (QDBusConnectionInterface *const sessionBusInterface = QDBusConnection::sessionBus().interface()) {
         /**
          * try to get the current running kate instances
          */
@@ -282,9 +277,7 @@ int main(int argc, char **argv)
         }
 
         QString currentActivity;
-        QDBusMessage m = QDBusMessage::createMethodCall(
-                                        QStringLiteral("org.kde.ActivityManager"),
-                                        QStringLiteral("/ActivityManager/Activities"), QStringLiteral("org.kde.ActivityManager.Activities"), QStringLiteral("CurrentActivity"));
+        QDBusMessage m = QDBusMessage::createMethodCall(QStringLiteral("org.kde.ActivityManager"), QStringLiteral("/ActivityManager/Activities"), QStringLiteral("org.kde.ActivityManager.Activities"), QStringLiteral("CurrentActivity"));
         QDBusMessage res = QDBusConnection::sessionBus().call(m);
         QList<QVariant> answer = res.arguments();
         if (answer.size() == 1) {
@@ -296,8 +289,7 @@ int main(int argc, char **argv)
             QString serviceName = (*it)->serviceName;
 
             if (currentActivity.length() != 0) {
-                QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
-                                        QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("isOnActivity"));
+                QDBusMessage m = QDBusMessage::createMethodCall(serviceName, QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("isOnActivity"));
 
                 QList<QVariant> dbargs;
 
@@ -326,7 +318,7 @@ int main(int argc, char **argv)
         QString start_session;
         bool session_already_opened = false;
 
-        //check if we try to start an already opened session
+        // check if we try to start an already opened session
         if (parser.isSet(startAnonymousSessionOption)) {
             force_new = true;
         } else if (parser.isSet(startSessionOption)) {
@@ -338,19 +330,17 @@ int main(int argc, char **argv)
             }
         }
 
-        //cleanup map
+        // cleanup map
         cleanupRunningKateAppInstanceMap(&mapSessionRii);
 
-        //if no new instance is forced and no already opened session is requested,
-        //check if a pid is given, which should be reused.
+        // if no new instance is forced and no already opened session is requested,
+        // check if a pid is given, which should be reused.
         // two possibilities: pid given or not...
         if ((!force_new) && serviceName.isEmpty()) {
             if ((parser.isSet(usePidOption)) || (!qgetenv("KATE_PID").isEmpty())) {
-                QString usePid = (parser.isSet(usePidOption)) ?
-                                parser.value(usePidOption) :
-                                QString::fromLocal8Bit(qgetenv("KATE_PID"));
+                QString usePid = (parser.isSet(usePidOption)) ? parser.value(usePidOption) : QString::fromLocal8Bit(qgetenv("KATE_PID"));
 
-                serviceName = QStringLiteral("org.kde.kate-") + usePid;
+                serviceName = QLatin1String("org.kde.kate-") + usePid;
                 if (!kateServices.contains(serviceName)) {
                     serviceName.clear();
                 }
@@ -362,7 +352,6 @@ int main(int argc, char **argv)
         if ((!force_new) && (serviceName.isEmpty())) {
             const int desktopnumber = KWindowSystem::currentDesktop();
             for (int s = 0; s < kateServices.count(); s++) {
-
                 serviceName = kateServices[s];
 
                 if (!serviceName.isEmpty()) {
@@ -370,8 +359,7 @@ int main(int argc, char **argv)
 
                     if (there.isValid() && there.value()) {
                         // query instance current desktop
-                        QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
-                                         QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("desktopNumber"));
+                        QDBusMessage m = QDBusMessage::createMethodCall(serviceName, QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("desktopNumber"));
 
                         QDBusMessage res = QDBusConnection::sessionBus().call(m);
                         QList<QVariant> answer = res.arguments();
@@ -390,7 +378,7 @@ int main(int argc, char **argv)
             }
         }
 
-        //check again if service is still running
+        // check again if service is still running
         foundRunningService = false;
         if (!serviceName.isEmpty()) {
             QDBusReply<bool> there = sessionBusInterface->isServiceRegistered(serviceName);
@@ -400,8 +388,7 @@ int main(int argc, char **argv)
         if (foundRunningService) {
             // open given session
             if (parser.isSet(startSessionOption) && (!session_already_opened)) {
-                QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
-                                QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("activateSession"));
+                QDBusMessage m = QDBusMessage::createMethodCall(serviceName, QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("activateSession"));
 
                 QList<QVariant> dbusargs;
                 dbusargs.append(parser.value(startSessionOption));
@@ -420,8 +407,7 @@ int main(int argc, char **argv)
             // Bug 397913: Reverse the order here so the new tabs are opened in same order as the files were passed in on the command line
             for (int i = urls.size() - 1; i >= 0; --i) {
                 const QString &url = urls[i];
-                QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
-                                QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("tokenOpenUrlAt"));
+                QDBusMessage m = QDBusMessage::createMethodCall(serviceName, QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("tokenOpenUrlAt"));
 
                 UrlInfo info(url);
                 QList<QVariant> dbusargs;
@@ -440,7 +426,7 @@ int main(int argc, char **argv)
                         QVariant v = res.arguments()[0];
                         if (v.isValid()) {
                             QString s = v.toString();
-                            if ((!s.isEmpty()) && (s != QStringLiteral("ERROR"))) {
+                            if ((!s.isEmpty()) && (s != QLatin1String("ERROR"))) {
                                 tokens << s;
                             }
                         }
@@ -452,8 +438,7 @@ int main(int argc, char **argv)
                 QTextStream input(stdin, QIODevice::ReadOnly);
 
                 // set chosen codec
-                QTextCodec *codec = parser.isSet(useEncodingOption) ?
-                                    QTextCodec::codecForName(parser.value(useEncodingOption).toUtf8()) : nullptr;
+                QTextCodec *codec = parser.isSet(useEncodingOption) ? QTextCodec::codecForName(parser.value(useEncodingOption).toUtf8()) : nullptr;
 
                 if (codec) {
                     input.setCodec(codec);
@@ -467,8 +452,7 @@ int main(int argc, char **argv)
                     text.append(line + QLatin1Char('\n'));
                 } while (!line.isNull());
 
-                QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
-                                QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("openInput"));
+                QDBusMessage m = QDBusMessage::createMethodCall(serviceName, QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("openInput"));
 
                 QList<QVariant> dbusargs;
                 dbusargs.append(text);
@@ -493,8 +477,7 @@ int main(int argc, char **argv)
             }
 
             if (nav) {
-                QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
-                                QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("setCursor"));
+                QDBusMessage m = QDBusMessage::createMethodCall(serviceName, QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("setCursor"));
 
                 QList<QVariant> args;
                 args.append(line);
@@ -505,8 +488,7 @@ int main(int argc, char **argv)
             }
 
             // activate the used instance
-            QDBusMessage activateMsg = QDBusMessage::createMethodCall(serviceName,
-                                    QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("activate"));
+            QDBusMessage activateMsg = QDBusMessage::createMethodCall(serviceName, QStringLiteral("/MainApplication"), QStringLiteral("org.kde.Kate.Application"), QStringLiteral("activate"));
             QDBusConnection::sessionBus().call(activateMsg);
 
             // connect dbus signal
@@ -526,12 +508,8 @@ int main(int argc, char **argv)
             // We don't want the session manager to restart us on next login
             // if we block
             if (needToBlock) {
-                QObject::connect(qApp, &QGuiApplication::saveStateRequest, qApp,
-                                 [](QSessionManager &session) {
-                                     session.setRestartHint(QSessionManager::RestartNever);
-                                 },
-                                 Qt::DirectConnection
-                         );
+                QObject::connect(
+                    qApp, &QGuiApplication::saveStateRequest, qApp, [](QSessionManager &session) { session.setRestartHint(QSessionManager::RestartNever); }, Qt::DirectConnection);
             }
 
             // this will wait until exiting is emitted by the used instance, if wanted...
@@ -568,7 +546,7 @@ int main(int argc, char **argv)
              */
             QVariantMap message;
             QVariantList messageUrls;
-            foreach(const QString & url, urls) {
+            for (const QString &url : urls) {
                 /**
                  * get url info and pack them into the message as extra element in urls list
                  */
@@ -629,15 +607,13 @@ int main(int argc, char **argv)
     /**
      * else: connect the single application notifications
      */
-    QObject::connect(&app, &SharedTools::QtSingleApplication::messageReceived,
-                     &kateApp, &KateApp::remoteMessageReceived);
+    QObject::connect(&app, &SharedTools::QtSingleApplication::messageReceived, &kateApp, &KateApp::remoteMessageReceived);
 
     KateMainWindow *win = kateApp.activeKateMainWindow();
     app.setActivationWindow(win, true);
 
 #endif
 
-
     /**
      * start main event loop for our application
      */
